/* Low Latency tools library */

#ifdef __IGNORE_getcpu
/*
 * getcpu is a vsyscall.
 * This means that sched_getcpu is supported through sched.h
 */
#include <sched.h>

#else
/* Determine the current processor */
int sched_getcpu(void);
#endif

/*
 * Timestamp functions
 *
 * Timestamp values are processor specific(!). The value of sched_getcpu()
 * must be the same in order for them to have a common timebase.
 */

unsigned long long timestamp_nanoseconds(void);
unsigned long long timestamp_femtoseconds(void);
unsigned long long timestamp_microseconds(void);

/*
 * Give the cpu some breathing room,
 * so that it cools down and lets other threads run.
 *
 * Put one of these into each busy loop.
 */
void cpu_relax(void);

/*
 * Initialize library. Pass 0 for sillent initialization.
 * 1 for verbose.
 */
void ll_init(int verbose);

/* Hardware description */
extern unsigned int processors;
extern unsigned int cores;
extern unsigned long cacheline_size;
extern unsigned long cpu_l3_cache_size;
extern unsigned long cpu_l2_cache_size;
extern unsigned long cpu_l1d_cache_size;
extern unsigned int cpu_l1i_cache_size;
extern char *cpu_name;
extern unsigned int cpu_family;
extern unsigned int cpu_model;
extern unsigned int cpu_stepping;
extern unsigned long long cpu_clock_frequency;


